package com.biganto.visual.roompark.conductor.dialogs

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.annotation.LayoutRes
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.domain.model.PhotoResolutionModel
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonRecyclerAdapter
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonViewHolder
import com.bluelinelabs.conductor.Controller
import com.google.android.material.textview.MaterialTextView


/**
 * Created by Vladislav Bogdashkin on 09.04.2019.
 */

internal const val  PHOTOS_KEY = "CHHOSE_PHOTO_LIST_KEY"

private fun formBundle(photos: ArrayList<PhotoResolutionModel>): Bundle {
    val b = Bundle()
    b.putParcelableArrayList(PHOTOS_KEY,photos)
    return b
}

class ChooseResolutionDialogController : Controller {

    constructor(args: Bundle) : super(args)

    constructor(photos: ArrayList<PhotoResolutionModel>) : super(formBundle(photos))

    lateinit var recyclerView : RecyclerView

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup): View {
        val view = inflater.inflate(getLayoutId(), container, false)

        recyclerView = view.findViewById(R.id.photoSizesRecyclerView)
        recyclerView.adapter = PhotoSizeAdapter()
        args.getParcelableArrayList<PhotoResolutionModel>(PHOTOS_KEY)?.let {
            (recyclerView.adapter as PhotoSizeAdapter).setItems(it)
        }

        return view
    }

    @LayoutRes
    fun getLayoutId() = R.layout.choose_size_modal_screen

    var dismissActionDelegate = {
        router.popCurrentController()
        Unit

//        args.putParcelableArrayList("sdsd", arrayListOf<PhotoModel>())
    }


}

private class PhotoSizeAdapter:CommonRecyclerAdapter<PhotoSizeViewHolder,PhotoResolutionModel>(){

    override val vhKlazz = PhotoSizeViewHolder::class
    override fun getVhLayout(): Int = R.layout.choose_size_viewholder

}

private class PhotoSizeViewHolder(itemView: View) :CommonViewHolder<PhotoResolutionModel>(itemView){

    @BindView(R.id.size_text)
    lateinit var textView : MaterialTextView

    override fun onViewBound(model: PhotoResolutionModel) {
        textView.text = model.resName
    }
}